==> bugslife_1_3_03.zip: bugslife_1_3_03/WEB-INF/src/jp/gr/java_conf/bugslife/form/BugDetail4Form.java <==
//===========================================================================
// package
//===========================================================================
package jp.gr.java_conf.bugslife.form;

//===========================================================================
// import
//===========================================================================
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;

import java.io.UnsupportedEncodingException;

import java.util.*;
import java.text.*;

import jp.gr.java_conf.bugslife.util.*;

/**
 *<PRE>
 * FormNX
 *
 *</PRE>
 * @author k@
 * @version 1.0.0
 */
public class BugDetail4Form extends ActionForm {
//===========================================================================
// attributes
//===========================================================================
	/**
	 * ANV
	 */
	private String m_action;
	/**
	 * ̏ԍ
	 */
	private int m_bno;
	/**
	 * ue
	 */
	private String m_addText;
	/**
	 * C\[X
	 */
	private String m_updateSrc;
	/**
	 * ChLg
	 */
	private String m_updateDoc;
	/**
	 * Tu~bg^Cv
	 */
	private String m_submitType = DEFAULT_STATUS;
	/**
	 * vXe[^X
	 */
	private String m_requestStatusWhitebord;
	/**
	 * vXe[^X
	 */
	private String m_requestStatus;
	/**
	 * CS
	 */
	private String m_requestUpdater;
	/**
	 * ͒S
	 */
	private String m_requestAnalyst;
	/**
	 * S
	 */
	private String m_requestAssigne;
	/**
	 * vR|[lghc
	 */
	private String m_requestCpid = null;
	/**
	 * [Mv
	 */
	private boolean m_dontSendMail;
	/**
	 * Log
	 */
	private Log log = LogFactory.getLog(this.getClass().getName());
//===========================================================================
// other attribute
//===========================================================================
	private static final String DEFAULT_STATUS = "resolvedIssuer";
	/**
	 * 񋟗\tH[}bg
	 */
	private static final String RELSCH_DATE_FORMAT = Converter.DATE_PATTAN;
	public static final int RELSCH_DATE = Converter.DATE;
//===========================================================================
// methods
//===========================================================================
	/**
	 * ANV̎擾
	 * 
	 * @return ANV
	 */
	public String getAction()
	{
		return m_action;
	}
	/**
	 * ANṼZbg
	 * 
	 * @param action ANV
	 */
	public void setAction(String action)
	{
		m_action = action;
	}
	/**
	 * ̏ԍ̎擾
	 * 
	 * @return ̏ԍ
	 */
	public int getBno()
	{
		return m_bno;
	}
	/**
	 * ̏ԍ̃Zbg
	 * 
	 * @param bno ̏ԍ
	 */
	public void setBno(int bno)
	{
		m_bno = bno;
	}
	/**
	 * A̎擾
	 * 
	 * @return A
	 */
	public String getAddText()
	{
		return m_addText;
	}
	/**
	 * ÃZbg
	 * 
	 * @param addText A
	 */
	public void setAddText(String addText)
	{
		m_addText = addText;
	}
	/**
	 * C\[X̎擾
	 * 
	 * @return C\[X
	 */
	public String getUpdateSrc()
	{
		return m_updateSrc;
	}
	/**
	 * C\[X̃Zbg
	 * 
	 * @param updateSrc C\[X
	 */
	public void setUpdateSrc(String updateSrc)
	{
		m_updateSrc = updateSrc;
	}
	/**
	 * ChLg̎擾
	 * 
	 * @return ChLg
	 */
	public String getUpdateDoc()
	{
		return m_updateDoc;
	}
	/**
	 * ChLg̃Zbg
	 * 
	 * @param updateDoc ChLg
	 */
	public void setUpdateDoc(String updateDoc)
	{
		m_updateDoc = updateDoc;
	}
	/**
	 * Tu~bg^Cv̎擾
	 * 
	 * @return Tu~bg^Cv
	 */
	public String getSubmitType()
	{
		return m_submitType;
	}
	/**
	 * Tu~bg^CṽZbg
	 * 
	 * @param submitType Tu~bg^Cv
	 */
	public void setSubmitType(String submitType)
	{
		m_submitType = submitType;
	}
	/**
	 * vXe[^X󋵂̎擾
	 * 
	 * @return vXe[^X
	 */
	public String getRequestStatusWhitebord()
	{
		return m_requestStatusWhitebord;
	}
	/**
	 * vXe[^X󋵂̃Zbg
	 * 
	 * @param requestStatusWhitebord vXe[^X
	 */
	public void setRequestStatusWhitebord(String requestStatusWhitebord)
	{
		m_requestStatusWhitebord = requestStatusWhitebord;
	}
	/**
	 * vXe[^X̎擾
	 * 
	 * @return vXe[^X
	 */
	public String getRequestStatus()
	{
		return m_requestStatus;
	}
	/**
	 * vXe[^X̃Zbg
	 * 
	 * @param requestStatus vXe[^X
	 */
	public void setRequestStatus(String requestStatus)
	{
		m_requestStatus = requestStatus;
	}
	/**
	 * CS҂̎擾
	 * 
	 * @return CS
	 */
	public String getRequestUpdater()
	{
		return m_requestUpdater;
	}
	/**
	 * CS҂̃Zbg
	 * 
	 * @param requestUpdater CS
	 */
	public void setRequestUpdater(String requestUpdater)
	{
		m_requestUpdater = requestUpdater;
	}
	/**
	 * ͒S҂̎擾
	 * 
	 * @return ͒S
	 */
	public String getRequestAnalyst()
	{
		return m_requestAnalyst;
	}
	/**
	 * ͒S҂̃Zbg
	 * 
	 * @param requestAnalyst ͒S
	 */
	public void setRequestAnalyst(String requestAnalyst)
	{
		m_requestAnalyst = requestAnalyst;
	}
	/**
	 * S҂̎擾
	 * 
	 * @return S
	 */
	public String getRequestAssigne()
	{
		return m_requestAssigne;
	}
	/**
	 * S҂̃Zbg
	 * 
	 * @param requestAssigne S
	 */
	public void setRequestAssigne(String requestAssigne)
	{
		m_requestAssigne = requestAssigne;
	}
	/**
	 * vR|[lghc̎擾
	 * 
	 * @return vR|[lghc
	 */
	public String getRequestCpid()
	{
		return m_requestCpid;
	}
	/**
	 * vR|[lghc̃Zbg
	 * 
	 * @param requestCpid vR|[lghc
	 */
	public void setRequestCpid(String requestCpid)
	{
		m_requestCpid = requestCpid;
	}
	/**
	 * M[vۂ̎擾
	 * 
	 * @return M[v
	 */
	public boolean getDontSendMail()
	{
		return m_dontSendMail;
	}
	/**
	 * M[vۂ̃Zbg
	 * 
	 * @param dontSendMail M[v
	 */
	public void setDontSendMail(boolean dontSendMail)
	{
		m_dontSendMail = dontSendMail;
	}
//===========================================================================
// Public Methods
//===========================================================================
	/**
	* Zbg
	*
	* @param mapping The mapping used to select this instance
	* @param request The servlet request we are processing
	*/
	public void reset(ActionMapping mapping, HttpServletRequest request) {
		
		//debug
		log.debug("reset");
		//encodeing Zbg
		try {
			request.setCharacterEncoding("SJIS");
		} catch (UnsupportedEncodingException e) {
			e.printStackTrace();
		}
		
		m_action = null;
		m_bno = 0;
		m_addText = null;
		m_updateSrc = null;
		m_updateDoc = null;
		m_submitType = DEFAULT_STATUS;
		m_requestStatusWhitebord = null;
		m_requestStatus = null;
		m_requestAssigne = null;
		m_requestUpdater = null;
		m_requestAnalyst = null;
		m_requestCpid = null;
		m_dontSendMail = false;
	}
	/**
	* ľ(Validate) 
	*
	* @param mapping The mapping used to select this instance
	* @param request The servlet request we are processing
	*/
	public ActionErrors validate(ActionMapping mapping,
								 HttpServletRequest request) {
		ActionErrors errors = new ActionErrors();
		
		log.debug("validate");
		
		//action
		Varidater.checkRequired(m_action, "action", errors);
		//submitType
		if (Varidater.checkSelected(m_submitType, "submitType", errors)) {
			//^CvʕK{`FbN
			if (m_submitType.equals("statusSelect")) {
				//issuDate
				Varidater.checkSelected(m_requestStatus, "requestStatus", errors);
			} else if (m_submitType.equals("statusDispatch")) {
				//requestAssigne
				Varidater.checkSelected(new Integer(m_requestAssigne), "requestAssigne", errors);
			}
		}
		return errors;
	}
}

==> bugslife_1_3_04.zip: bugslife_1_3_04/WEB-INF/src/jp/gr/java_conf/bugslife/form/BugDetail4Form.java <==
//===========================================================================
// package
//===========================================================================
package jp.gr.java_conf.bugslife.form;

//===========================================================================
// import
//===========================================================================
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;

import java.io.UnsupportedEncodingException;

import java.util.*;
import java.text.*;

import jp.gr.java_conf.bugslife.util.*;

/**
 *<PRE>
 * FormNX
 *
 *</PRE>
 * @author k@
 * @version 1.0.0
 */
public class BugDetail4Form extends ActionForm {
//===========================================================================
// attributes
//===========================================================================
	/**
	 * ANV
	 */
	private String m_action;
	/**
	 * ̏ԍ
	 */
	private int m_bno;
	/**
	 * ue
	 */
	private String m_addText;
	/**
	 * C\[X
	 */
	private String m_updateSrc;
	/**
	 * ChLg
	 */
	private String m_updateDoc;
	/**
	 * Tu~bg^Cv
	 */
	private String m_submitType = DEFAULT_STATUS;
	/**
	 * vXe[^X
	 */
	private String m_requestStatusWhitebord;
	/**
	 * vXe[^X
	 */
	private String m_requestStatus;
	/**
	 * mFS
	 */
	private String m_requestResolver;
	/**
	 * CS
	 */
	private String m_requestUpdater;
	/**
	 * ͒S
	 */
	private String m_requestAnalyst;
	/**
	 * S
	 */
	private String m_requestAssigne;
	/**
	 * vR|[lghc
	 */
	private String m_requestCpid = null;
	/**
	 * [Mv
	 */
	private boolean m_dontSendMail;
	/**
	 * Log
	 */
	private Log log = LogFactory.getLog(this.getClass().getName());
//===========================================================================
// other attribute
//===========================================================================
	private static final String DEFAULT_STATUS = "resolvedIssuer";
	/**
	 * 񋟗\tH[}bg
	 */
	private static final String RELSCH_DATE_FORMAT = Converter.DATE_PATTAN;
	public static final int RELSCH_DATE = Converter.DATE;
//===========================================================================
// methods
//===========================================================================
	/**
	 * ANV̎擾
	 * 
	 * @return ANV
	 */
	public String getAction()
	{
		return m_action;
	}
	/**
	 * ANṼZbg
	 * 
	 * @param action ANV
	 */
	public void setAction(String action)
	{
		m_action = action;
	}
	/**
	 * ̏ԍ̎擾
	 * 
	 * @return ̏ԍ
	 */
	public int getBno()
	{
		return m_bno;
	}
	/**
	 * ̏ԍ̃Zbg
	 * 
	 * @param bno ̏ԍ
	 */
	public void setBno(int bno)
	{
		m_bno = bno;
	}
	/**
	 * A̎擾
	 * 
	 * @return A
	 */
	public String getAddText()
	{
		return m_addText;
	}
	/**
	 * ÃZbg
	 * 
	 * @param addText A
	 */
	public void setAddText(String addText)
	{
		m_addText = addText;
	}
	/**
	 * C\[X̎擾
	 * 
	 * @return C\[X
	 */
	public String getUpdateSrc()
	{
		return m_updateSrc;
	}
	/**
	 * C\[X̃Zbg
	 * 
	 * @param updateSrc C\[X
	 */
	public void setUpdateSrc(String updateSrc)
	{
		m_updateSrc = updateSrc;
	}
	/**
	 * ChLg̎擾
	 * 
	 * @return ChLg
	 */
	public String getUpdateDoc()
	{
		return m_updateDoc;
	}
	/**
	 * ChLg̃Zbg
	 * 
	 * @param updateDoc ChLg
	 */
	public void setUpdateDoc(String updateDoc)
	{
		m_updateDoc = updateDoc;
	}
	/**
	 * Tu~bg^Cv̎擾
	 * 
	 * @return Tu~bg^Cv
	 */
	public String getSubmitType()
	{
		return m_submitType;
	}
	/**
	 * Tu~bg^CṽZbg
	 * 
	 * @param submitType Tu~bg^Cv
	 */
	public void setSubmitType(String submitType)
	{
		m_submitType = submitType;
	}
	/**
	 * vXe[^X󋵂̎擾
	 * 
	 * @return vXe[^X
	 */
	public String getRequestStatusWhitebord()
	{
		return m_requestStatusWhitebord;
	}
	/**
	 * vXe[^X󋵂̃Zbg
	 * 
	 * @param requestStatusWhitebord vXe[^X
	 */
	public void setRequestStatusWhitebord(String requestStatusWhitebord)
	{
		m_requestStatusWhitebord = requestStatusWhitebord;
	}
	/**
	 * vXe[^X̎擾
	 * 
	 * @return vXe[^X
	 */
	public String getRequestStatus()
	{
		return m_requestStatus;
	}
	/**
	 * vXe[^X̃Zbg
	 * 
	 * @param requestStatus vXe[^X
	 */
	public void setRequestStatus(String requestStatus)
	{
		m_requestStatus = requestStatus;
	}
	/**
	 * mFS҂̎擾
	 * 
	 * @return mFS
	 */
	public String getRequestResolver()
	{
		return m_requestResolver;
	}
	/**
	 * mFS҂̃Zbg
	 * 
	 * @param requestUpdater mFS
	 */
	public void setRequestResolver(String requestResolver)
	{
		m_requestResolver = requestResolver;
	}
	/**
	 * CS҂̎擾
	 * 
	 * @return CS
	 */
	public String getRequestUpdater()
	{
		return m_requestUpdater;
	}
	/**
	 * CS҂̃Zbg
	 * 
	 * @param requestUpdater CS
	 */
	public void setRequestUpdater(String requestUpdater)
	{
		m_requestUpdater = requestUpdater;
	}
	/**
	 * ͒S҂̎擾
	 * 
	 * @return ͒S
	 */
	public String getRequestAnalyst()
	{
		return m_requestAnalyst;
	}
	/**
	 * ͒S҂̃Zbg
	 * 
	 * @param requestAnalyst ͒S
	 */
	public void setRequestAnalyst(String requestAnalyst)
	{
		m_requestAnalyst = requestAnalyst;
	}
	/**
	 * S҂̎擾
	 * 
	 * @return S
	 */
	public String getRequestAssigne()
	{
		return m_requestAssigne;
	}
	/**
	 * S҂̃Zbg
	 * 
	 * @param requestAssigne S
	 */
	public void setRequestAssigne(String requestAssigne)
	{
		m_requestAssigne = requestAssigne;
	}
	/**
	 * vR|[lghc̎擾
	 * 
	 * @return vR|[lghc
	 */
	public String getRequestCpid()
	{
		return m_requestCpid;
	}
	/**
	 * vR|[lghc̃Zbg
	 * 
	 * @param requestCpid vR|[lghc
	 */
	public void setRequestCpid(String requestCpid)
	{
		m_requestCpid = requestCpid;
	}
	/**
	 * M[vۂ̎擾
	 * 
	 * @return M[v
	 */
	public boolean getDontSendMail()
	{
		return m_dontSendMail;
	}
	/**
	 * M[vۂ̃Zbg
	 * 
	 * @param dontSendMail M[v
	 */
	public void setDontSendMail(boolean dontSendMail)
	{
		m_dontSendMail = dontSendMail;
	}
//===========================================================================
// Public Methods
//===========================================================================
	/**
	* Zbg
	*
	* @param mapping The mapping used to select this instance
	* @param request The servlet request we are processing
	*/
	public void reset(ActionMapping mapping, HttpServletRequest request) {
		
		//debug
		log.debug("reset");
		//encodeing Zbg
		try {
			request.setCharacterEncoding("SJIS");
		} catch (UnsupportedEncodingException e) {
			e.printStackTrace();
		}
		
		m_action = null;
		m_bno = 0;
		m_addText = null;
		m_updateSrc = null;
		m_updateDoc = null;
		m_submitType = DEFAULT_STATUS;
		m_requestStatusWhitebord = null;
		m_requestStatus = null;
		m_requestAssigne = null;
		m_requestResolver = null;
		m_requestUpdater = null;
		m_requestAnalyst = null;
		m_requestCpid = null;
		m_dontSendMail = false;
	}
	/**
	* ľ(Validate) 
	*
	* @param mapping The mapping used to select this instance
	* @param request The servlet request we are processing
	*/
	public ActionErrors validate(ActionMapping mapping,
								 HttpServletRequest request) {
		ActionErrors errors = new ActionErrors();
		
		log.debug("validate");
		
		//action
		Varidater.checkRequired(m_action, "action", errors);
		//submitType
		if (Varidater.checkSelected(m_submitType, "submitType", errors)) {
			//^CvʕK{`FbN
			if (m_submitType.equals("statusSelect")) {
				//issuDate
				Varidater.checkSelected(m_requestStatus, "requestStatus", errors);
			} else if (m_submitType.equals("statusDispatch")) {
				//requestAssigne
				Varidater.checkSelected(new Integer(m_requestAssigne), "requestAssigne", errors);
			}
		}
		return errors;
	}
}
